# Octopy-Energy

Python client for the Octopus energy API

<br>

To Do

- [ ] Add in handler to collect all pages
- [ ] Finish writing docstrings
- [ ] Publish to PyPi
- [ ] Add MkDocs 
- [ ] Github actions launching docs
